package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBillsInspectInstance;

/**
 * 巡检工单Mapper接口
 *
 * @author Open Platform
 * @date 2024-01-23
 */
public interface DmsBillsInspectInstanceMapper
{
    /**
     * 查询巡检工单
     *
     * @param inspectInstanceId 巡检工单主键
     * @return 巡检工单
     */
    public DmsBillsInspectInstance selectDmsBillsInspectInstanceByInspectInstanceId(Long inspectInstanceId);
    public List<DmsBillsInspectInstance> selectPoint();
    public List<DmsBillsInspectInstance> selectInspection();
    /**
     * 查询巡检工单列表
     *
     * @param dmsBillsInspectInstance 巡检工单
     * @return 巡检工单集合
     */
    public List<DmsBillsInspectInstance> selectDmsBillsInspectInstanceList(DmsBillsInspectInstance dmsBillsInspectInstance);

    /**
     * 新增巡检工单
     *
     * @param dmsBillsInspectInstance 巡检工单
     * @return 结果
     */
    public int insertDmsBillsInspectInstance(DmsBillsInspectInstance dmsBillsInspectInstance);

    /**
     * 修改巡检工单
     *
     * @param dmsBillsInspectInstance 巡检工单
     * @return 结果
     */
    public int updateDmsBillsInspectInstance(DmsBillsInspectInstance dmsBillsInspectInstance);

    /**
     * 删除巡检工单
     *
     * @param inspectInstanceId 巡检工单主键
     * @return 结果
     */
    public int deleteDmsBillsInspectInstanceByInspectInstanceId(Long inspectInstanceId);

    /**
     * 批量删除巡检工单
     *
     * @param inspectInstanceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBillsInspectInstanceByInspectInstanceIds(Long[] inspectInstanceIds);

    int insertDmsBillsInspectInstancePDA(DmsBillsInspectInstance dmsBillsInspectInstance);


    /**
     * 查询最新一条巡检工单列表
     *
     * @param dmsBillsInspectInstance 巡检工单
     * @return 巡检工单
     */
    public DmsBillsInspectInstance selectNewestDmsBillsInspectInstance(DmsBillsInspectInstance dmsBillsInspectInstance);


}
